.. _compare:

################
Comparison Table
################

.. currentmodule:: fitbenchmarking.results_processing.compare_table
.. autoclass:: fitbenchmarking.results_processing.compare_table.CompareTable
	       :noindex:
